@@ -26,6 +26,7 @@ ARTEFACTS = [
     "bzImage.gz",
     "zImage.xz",
     "modules.tar.xz",
+    "tf-bl1.bin",
     "mcp_fw.bin",
     "mcp_romfw.bin",
     "android-nano.img.xz",
@@ -33,10 +34,12 @@ ARTEFACTS = [
     "core-image-minimal-morello-fvp.wic",
     "scp_fw.bin",
     "scp_romfw.bin",
-    "uefi.bin",
+    "fip.bin",
 ]
 
 FVP_MORELLO_ANDROID = [
+    "--ap-romfw",
+    "tf-bl1.bin",
     "--mcp-fw",
     "mcp_fw.bin",
     "--mcp-romfw",
@@ -47,8 +50,8 @@ FVP_MORELLO_ANDROID = [
     "scp_fw.bin",
     "--scp-romfw",
     "scp_romfw.bin",
-    "--uefi",
-    "uefi.bin",
+    "--fip",
+    "fip.bin",
 ]
 
 metadata = {
@@ -121,6 +124,19 @@ def artefacts(tmp_path):
             ["--device", "qemu-i386", "--tests", "kunit"],
             "qemu-i386-kunit.yaml",
         ),
+        (
+            [
+                "--device",
+                "qemu-i386",
+                "--tests",
+                "kunit",
+                "--overlay",
+                "http://example.com/overlay1.tar.xz",
+                "--overlay",
+                "http://example.com/overlay2.tar.xz",
+            ],
+            "qemu-i386-kunit-overlays.yaml",
+        ),
         (
             ["--device", "qemu-i386", "--kernel", "bzImage.gz"],
             "qemu-i386-kernel-gz.yaml",
@@ -129,6 +145,28 @@ def artefacts(tmp_path):
             ["--device", "qemu-mips32"],
             "qemu-mips32.yaml",
         ),
+        (
+            [
+                "--device",
+                "qemu-mips32",
+                "--modules",
+                "https://example.com/modules.tar.xz",
+            ],
+            "qemu-mips32-modules.yaml",
+        ),
+        (
+            [
+                "--device",
+                "qemu-mips32",
+                "--modules",
+                "https://example.com/modules.tar.xz",
+                "--overlay",
+                "http://example.com/overlay2.tar.xz",
+                "--tests",
+                "kunit",
+            ],
+            "qemu-mips32-modules-overlays-kunit.yaml",
+        ),
         (
             ["--device", "qemu-mips32", "--", "cat", "/proc/cpuinfo"],
             "qemu-mips32-command.yaml",
@@ -157,6 +195,14 @@ def artefacts(tmp_path):
             ["--device", "qemu-ppc64le"],
             "qemu-ppc64le.yaml",
         ),
+        (
+            ["--device", "qemu-s390"],
+            "qemu-s390.yaml",
+        ),
+        (
+            ["--device", "qemu-s390", "--tests", "ltp-smoke"],
+            "qemu-s390-ltp-smoke.yaml",
+        ),
         (
             ["--device", "qemu-riscv64"],
             "qemu-riscv64.yaml",
@@ -354,6 +400,8 @@ def artefacts(tmp_path):
             [
                 "--device",
                 "fvp-morello-busybox",
+                "--ap-romfw",
+                "tf-bl1.bin",
                 "--mcp-fw",
                 "mcp_fw.bin",
                 "--mcp-romfw",
@@ -364,8 +412,8 @@ def artefacts(tmp_path):
                 "scp_fw.bin",
                 "--scp-romfw",
                 "scp_romfw.bin",
-                "--uefi",
-                "uefi.bin",
+                "--fip",
+                "fip.bin",
             ],
             "fvp-morello-busybox.yaml",
         ),
@@ -373,6 +421,8 @@ def artefacts(tmp_path):
             [
                 "--device",
                 "fvp-morello-oe",
+                "--ap-romfw",
+                "tf-bl1.bin",
                 "--mcp-fw",
                 "mcp_fw.bin",
                 "--mcp-romfw",
@@ -383,8 +433,8 @@ def artefacts(tmp_path):
                 "scp_fw.bin",
                 "--scp-romfw",
                 "scp_romfw.bin",
-                "--uefi",
-                "uefi.bin",
+                "--fip",
+                "fip.bin",
             ],
             "fvp-morello-oe.yaml",
         ),
@@ -392,6 +442,8 @@ def artefacts(tmp_path):
             [
                 "--device",
                 "fvp-morello-ubuntu",
+                "--ap-romfw",
+                "tf-bl1.bin",
                 "--mcp-fw",
                 "mcp_fw.bin",
                 "--mcp-romfw",
@@ -400,8 +452,8 @@ def artefacts(tmp_path):
                 "scp_fw.bin",
                 "--scp-romfw",
                 "scp_romfw.bin",
-                "--uefi",
-                "uefi.bin",
+                "--fip",
+                "fip.bin",
             ],
             "fvp-morello-ubuntu.yaml",
         ),
