@@ -60,15 +60,17 @@ def run(options, tmpdir: Path) -> int:
         if options.modules:
             overlays.append(("modules", options.modules))
             extra_assets.append(options.modules)
-        for item in options.overlays:
-            name = str(hash(item)).replace("-", "n")
-            overlays.append((name, item))
+        for (index, item) in enumerate(options.overlays):
+            overlays.append((f"overlay-{index:02}", item))
             extra_assets.append(item)
 
-        test_definitions = "file://" + get_test_definitions(
-            TTYProgressIndicator("Downloading test definitions")
-        )
-        extra_assets.append(test_definitions)
+        # Add test definitions only when needed
+        test_definitions = None
+        if any(t.need_test_definition for t in options.tests):
+            test_definitions = "file://" + get_test_definitions(
+                TTYProgressIndicator("Downloading test definitions")
+            )
+            extra_assets.append(test_definitions)
 
         command = " ".join([shlex.quote(s) for s in options.command])
 
@@ -78,8 +80,10 @@ def run(options, tmpdir: Path) -> int:
             device=options.device,
             dtb=options.dtb,
             kernel=options.kernel,
+            ap_romfw=options.ap_romfw,
             mcp_fw=options.mcp_fw,
             mcp_romfw=options.mcp_romfw,
+            fip=options.fip,
             overlays=overlays,
             rootfs=options.rootfs,
             rootfs_partition=options.partition,
@@ -91,7 +95,6 @@ def run(options, tmpdir: Path) -> int:
             timeouts=options.timeouts,
             tmpdir=tmpdir,
             tux_boot_args=options.boot_args.replace('"', ""),
-            uefi=options.uefi,
             parameters=options.parameters,
         )
         LOG.debug("job definition")
@@ -137,7 +140,8 @@ def run(options, tmpdir: Path) -> int:
         options.rootfs,
         options.scp_fw,
         options.scp_romfw,
-        options.uefi,
+        options.ap_romfw,
+        options.fip,
     ] + extra_assets:
         if not path:
             continue
