@@ -25,9 +25,7 @@ class QemuDevice(Device):
     cpu: str = ""
     memory: str = ""
 
-    guestfs_interface: str = ""
     extra_options: List[str] = []
-    extra_options_tests: List[str] = []
 
     console: str = ""
     rootfs_dev: str = ""
@@ -52,11 +50,11 @@ class QemuDevice(Device):
         tests,
         **kwargs,
     ):
-        invalid_args = ["--" + k.replace("_", "-") for k in kwargs if kwargs[k]]
+        invalid_args = ["--" + k.replace("_", "-") for (k, v) in kwargs.items() if v]
 
         if len(invalid_args) > 0:
             raise InvalidArgument(
-                f"Invalid option(s) for qemu devices: {', '.join(invalid_args)}"
+                f"Invalid option(s) for qemu devices: {', '.join(sorted(invalid_args))}"
             )
 
         if bios and self.name != "qemu-riscv64":
@@ -82,10 +80,7 @@ class QemuDevice(Device):
         kwargs["machine"] = self.machine
         kwargs["cpu"] = self.cpu
         kwargs["memory"] = self.memory
-        kwargs["guestfs_interface"] = self.guestfs_interface
         kwargs["extra_options"] = self.extra_options.copy()
-        if kwargs["tests"]:
-            kwargs["extra_options"].extend(self.extra_options_tests.copy())
         kwargs["console"] = self.console
         kwargs["rootfs_dev"] = self.rootfs_dev
         kwargs["rootfs_arg"] = self.rootfs_arg
@@ -132,7 +127,6 @@ class QemuArm64(QemuDevice):
     machine = "virt,gic-version=3"
     cpu = "cortex-a57"
 
-    guestfs_interface = "virtio"
     extra_options = ["-smp 2"]
 
     console = "ttyAMA0"
@@ -151,7 +145,6 @@ class QemuArmv5(QemuDevice):
     machine = "versatilepb"
     cpu = "arm926"
 
-    guestfs_interface = "scsi"
     memory = "256M"
 
     console = "ttyAMA0"
@@ -171,9 +164,7 @@ class QemuArmv7(QemuDevice):
     machine = "virt,gic-version=3"
     cpu = "cortex-a15"
 
-    guestfs_interface = "none"
     extra_options = ["-smp 2"]
-    extra_options_tests = ["-device virtio-blk-device,drive=lavatest"]
 
     console = "ttyAMA0"
     rootfs_dev = "/dev/vda"
@@ -241,7 +232,7 @@ class QemuMips64(QemuDevice):
     machine = "malta"
 
     console = "ttyS0"
-    rootfs_dev = "/dev/hda"
+    rootfs_dev = "/dev/sda"
     rootfs_arg = "-drive file={rootfs},if=ide,format=raw"
 
     kernel = "https://storage.tuxboot.com/mips64/vmlinux"
@@ -256,7 +247,7 @@ class QemuMips64EL(QemuDevice):
     machine = "malta"
 
     console = "ttyS0"
-    rootfs_dev = "/dev/hda"
+    rootfs_dev = "/dev/sda"
     rootfs_arg = "-drive file={rootfs},if=ide,format=raw"
 
     kernel = "https://storage.tuxboot.com/mips64el/vmlinux"
@@ -271,8 +262,6 @@ class QemuPPC32(QemuDevice):
     machine = "ppce500"
     cpu = "e500mc"
 
-    guestfs_interface = "virtio"
-
     console = "ttyS0"
     rootfs_dev = "/dev/vda"
     rootfs_arg = "-drive file={rootfs},format=raw,if=virtio"
@@ -289,7 +278,6 @@ class QemuPPC64(QemuDevice):
     machine = "pseries"
     cpu = "POWER8"
 
-    guestfs_interface = "scsi,index=1"
     extra_options = ["-smp 2"]
 
     console = "hvc0"
@@ -308,7 +296,6 @@ class QemuPPC64LE(QemuDevice):
     machine = "pseries"
     cpu = "POWER8"
 
-    guestfs_interface = "scsi,index=1"
     extra_options = ["-smp 2"]
 
     console = "hvc0"
@@ -327,7 +314,6 @@ class QemuRiscV64(QemuDevice):
     machine = "virt"
     cpu = "rv64"
 
-    guestfs_interface = "virtio"
     extra_options = ["-smp 2"]
 
     console = "ttyS0"
@@ -341,6 +327,26 @@ class QemuRiscV64(QemuDevice):
     rootfs = "https://storage.tuxboot.com/riscv64/rootfs.ext4.zst"
 
 
+class QemuS390(QemuDevice):
+    name = "qemu-s390"
+
+    arch = "s390"
+    lava_arch = "s390x"
+    machine = "s390-ccw-virtio"
+    cpu = "max,zpci=on"
+
+    extra_options = ["-smp 2"]
+
+    console = "ttyS0"
+    rootfs_dev = "/dev/vda net.ifnames=0"
+    rootfs_arg = (
+        "-drive file={rootfs},if=none,format=raw,id=hd0 -device virtio-blk,drive=hd0"
+    )
+
+    kernel = "https://storage.tuxboot.com/s390/bzImage"
+    rootfs = "https://storage.tuxboot.com/s390/rootfs.ext4.zst"
+
+
 class QemuSPARC64(QemuDevice):
     name = "qemu-sparc64"
 
