@@ -25,10 +25,10 @@ class MorelloTest(Test):
         super().validate(device=device, parameters=parameters, **kwargs)
         missing = set(self.parameters) - set(parameters.keys())
         if missing:
-            raise InvalidArgument(f"Missing --parameters {', '.join(missing)}")
+            raise InvalidArgument(f"Missing --parameters {', '.join(sorted(missing))}")
         invalid = set(parameters.keys()) - set(self.parameters)
         if invalid:
-            raise InvalidArgument(f"Invalid --parameters {', '.join(invalid)}")
+            raise InvalidArgument(f"Invalid --parameters {', '.join(sorted(invalid))}")
 
     def render(self, **kwargs):
         kwargs["name"] = self.name
@@ -107,6 +107,7 @@ class MorelloFWTS(MorelloTest):
     timeout = 120
     device = "fvp-morello-oe"
     template = "fwts.yaml.jinja2"
+    need_test_definition = True
 
 
 class MorelloLibJPEGTurbo(MorelloAndroidTest):
